@@ -67,7 +67,8 @@ test_that("lillie.test is NA..", {
 })
 
 test_that("lillie.test is computed...", {
-        expect_true(
+        
+        skip_on_cran()   
                 EarlyConservationTest(
                         PhyloExpressionSetExample,
                         modules = list(
@@ -77,8 +78,8 @@ test_that("lillie.test is computed...", {
                         ),
                         permutations = 1000,
                         lillie.test = TRUE
-                )$lillie.test %in% c(TRUE, FALSE)
-        )
+                )$lillie.test
+        
         
 })
 
@@ -105,33 +106,34 @@ test_that("error occurs when modules aren't specified...", {
 })
 
 
-TestBootMatrix <- bootMatrix(PhyloExpressionSetExample, 1000)
-
-res <- EarlyConservationTest(
-        PhyloExpressionSetExample,
-        modules = list(
-                early = 1:2,
-                mid = 3:5,
-                late = 6:7
-        ),
-        custom.perm.matrix = TestBootMatrix
-)
-
-estimates <-
-        fitdistrplus::fitdist(apply(
-                TestBootMatrix,
-                1,
-                ecScore,
-                early = 1:2,
-                mid = 3:5,
-                late = 6:7
-        ),
-        distr = "norm")
-
-real_score <- ecScore(TAI(PhyloExpressionSetExample), 1:2, 3:5, 6:7)
 
 test_that("EarlyConservationTest() computes correct std.dev and p.values values...",
           {
+                  skip_on_cran()
+                  TestBootMatrix <- bootMatrix(PhyloExpressionSetExample, 1000)
+                  
+                  res <- EarlyConservationTest(
+                          PhyloExpressionSetExample,
+                          modules = list(
+                                  early = 1:2,
+                                  mid = 3:5,
+                                  late = 6:7
+                          ),
+                          custom.perm.matrix = TestBootMatrix
+                  )
+                  
+                  estimates <-
+                          fitdistrplus::fitdist(apply(
+                                  TestBootMatrix,
+                                  1,
+                                  ecScore,
+                                  early = 1:2,
+                                  mid = 3:5,
+                                  late = 6:7
+                          ),
+                          distr = "norm")
+                  
+                  real_score <- ecScore(TAI(PhyloExpressionSetExample), 1:2, 3:5, 6:7)
                   expect_equal(
                           res$p.value,
                           pnorm(
